IntervalsSingle

Struct IntervalsSingle 

pub struct IntervalsSingle<E, V> { /* private fields */ }
An Intervals stream containing a single Interval.

This is the simplest way to lift an Interval into the Intervals trait so it can participate in composition (&, |, etc.).

Implementations

Source

impl<E, V> IntervalsSingle<E, V>

pub fn new(v: Interval<E, V>) -> Self

Wrap a single Interval.

Examples found in repository?
examples/shift.rs (line 10)
7fn main() {
8    // [1, 4)
9    let i = Interval::new(EndpointOC::Closed(1), EndpointOC::Open(4), ());
10    let is = IntervalsSingle::new(i);
11
12    // Shift everything by +5 → [6, 9)
13    for iv in IntervalShift::new(is, 5).into_iter() {
14        println!("{:?}", iv);
15    }
16}
More examples
Hide additional examples
examples/union.rs (line 16)
10fn main() {
11    // [1, 3] tagged "A"
12    let ia = Interval::new(EndpointOC::Closed(1), EndpointOC::Closed(3), "A");
13    // (2, 4) tagged "B"
14    let ib = Interval::new(EndpointOC::Open(2), EndpointOC::Open(4), "B");
15
16    let isa = IntervalsSingle::new(ia);
17    let isb = IntervalsSingle::new(ib);
18
19    // Union: [1,2] -> (Some("A"), None), (2,3] -> (Some("A"), Some("B")), (3,4) -> (None, Some("B"))
20    for iv in or(isa, isb).into_iter() {
21        println!("{:?}", iv);
22    }
23}
examples/intersection.rs (line 13)
7fn main() {
8    // [1, 3] tagged "A"
9    let ia = Interval::new(EndpointOC::Closed(1), EndpointOC::Closed(3), "A");
10    // (2, 4) tagged "B"
11    let ib = Interval::new(EndpointOC::Open(2), EndpointOC::Open(4), "B");
12
13    let isa = IntervalsSingle::new(ia);
14    let isb = IntervalsSingle::new(ib);
15
16    // Intersection: (2, 3] tagged ("A", "B")
17    let result = and(isa, isb).into_iter().collect::<Vec<_>>();
18
19    for iv in &result {
20        println!("{:?}", iv);
21    }
22
23    assert_eq!(result.len(), 1);
24    assert_eq!(
25        result[0],
26        Interval::new(EndpointOC::Open(2), EndpointOC::Closed(3), ("A", "B"))
27    );
28}